#
# spec file for package slick-greeter
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name   lightdm-slick-greeter
Name:           slick-greeter
Version:        1.0.8
Release:        2.1
Summary:        The slick-looking login screen application
License:        GPL-3.0 and CC-BY-SA-3.0
Group:          System/X11/Displaymanagers
Url:            https://github.com/linuxmint/slick-greeter
Source:         https://github.com/linuxmint/slick-greeter/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# Some documentation for people writing branding packages, shipped in the branding-upstream package.
Source1:        README.GSettings-overrides
BuildRequires:  gnome-common
BuildRequires:  pkgconfig
BuildRequires:  vala >= 0.24
BuildRequires:  pkgconfig(cairo-ft)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gdk-x11-3.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(liblightdm-gobject-1) >= 1.12.0
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)

%description
The slick-looking greeter (login screen) application.
It is implemented as a LightDM greeter.

%package -n %{_name}
Summary:        The slick-looking login screen application
Group:          System/X11/Displaymanagers
Requires:       lightdm
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     %{_name}-lang
Provides:       lightdm-greeter
%glib2_gsettings_schema_requires

%description -n %{_name}
The slick-looking greeter (login screen) application.
It is implemented as a LightDM greeter.

%lang_package -n %{_name}

%package -n %{_name}-branding-upstream
Summary:        Upstream branding of %{_name}
Group:          System/X11/Displaymanagers
Requires:       %{_name} = %{version}
Requires:       gnome-icon-theme
Requires:       gtk3-metatheme-adwaita
Requires:       ubuntu-fonts
Supplements:    packageand(%{_name}:branding-upstream)
Conflicts:      otherproviders(%{_name}-branding)
Provides:       %{_name}-branding = %{version}
BuildArch:      noarch
#BRAND: A /usr/share/glib-2.0/schemas/$NAME.gschema.override file can
#BRAND: be used to override the default value for GSettings keys. See
#BRAND: README.GSettings-overrides for more details. The branding
#BRAND: package should then have proper Requires for features changed
#BRAND: with such an override file.

%description -n %{_name}-branding-upstream
This package provides the upstream look and feel for
lightdm-slick-greeter.

%prep
%setup -q
cp -a %{SOURCE1} .

%build
NOCONFIGURE=1 gnome-autogen.sh
%configure
make %{?_smp_mflags} V=1

%install
%make_install
%find_lang %{name}

%if 0%{?suse_version} >= 1320
mkdir -p %{buildroot}%{_sysconfdir}/alternatives/
touch %{buildroot}%{_sysconfdir}/alternatives/lightdm-default-greeter.desktop
ln -s %{_sysconfdir}/alternatives/lightdm-default-greeter.desktop \
  %{buildroot}%{_datadir}/xgreeters/lightdm-default-greeter.desktop
%endif

%post -n %{_name}
%glib2_gsettings_schema_post
update-alternatives --install \
  %{_datadir}/xgreeters/lightdm-default-greeter.desktop \
  lightdm-default-greeter.desktop \
  %{_datadir}/xgreeters/%{name}.desktop \
  10

%postun -n %{_name}
%glib2_gsettings_schema_postun
if [ "$1" = 0 ]; then
    update-alternatives --remove \
      lightdm-default-greeter.desktop \
      %{_datadir}/xgreeters/%{name}.desktop
fi

%files -n %{_name}
%defattr(-,root,root)
%doc COPYING README.md
%{_sbindir}/%{name}
%{_bindir}/%{name}-set-keyboard-layout
%{_bindir}/%{name}-check-hidpi
%{_datadir}/%{name}/
%dir %{_datadir}/xgreeters/
%{_datadir}/xgreeters/%{name}.desktop
%if 0%{?suse_version} >= 1320
%{_datadir}/xgreeters/lightdm-default-greeter.desktop
%else
%ghost %attr(0644,root,root) %{_datadir}/xgreeters/lightdm-default-greeter.desktop
%endif
%ghost %attr(0644,root,root) %{_sysconfdir}/alternatives/lightdm-default-greeter.desktop
%{_datadir}/glib-2.0/schemas/*%{name}.gschema.xml
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/%{name}-check-hidpi.1%{?ext_man}

%files -n %{_name}-lang -f %{name}.lang
%defattr(-,root,root)

%files -n %{_name}-branding-upstream
%defattr(-,root,root)
%doc README.GSettings-overrides

%changelog
* Wed Jun 21 2017 sor.alexei@meowr.ru
- Update to version 1.0.8:
  * Kill onboard and orca on session startup.
* Fri Jun 16 2017 sor.alexei@meowr.ru
- Update to version 1.0.7:
  * Badges: Don't hardcode any logic related to badge names.
  * Badges: Prefer SVG over PNG.
  * badges: Convert some badges to svg.
  * Describe options in the README and the man page.
  * badges: more svg converts.
  * Add plasma to the list of default sessions.
  * A11y: Fix HighContrast option.
  * Remove condescending comment in the code.
  * Explicitly set the keyboard layout.
  * Increase onscreen keyboard height.
  * Make error text bold and yellow.
* Fri Jun  9 2017 sor.alexei@meowr.ru
- Update to version 1.0.6 (changes since 1.0.4):
  * backgrounds: Fix determination of what to display as a
    background.
  * Fix prompt display in GTK+ 3.20 or newer.
  * Background: If no user background is set/used, fallback to the
    system background.
* Wed May 24 2017 sor.alexei@meowr.ru
- Update to version 1.0.4:
  * Handle errors from liblightdm.
  * dash-entry.vala: Improve position of the hint text draw in the
    password entry box - it should be more centred now instead of
    in the upper left corner.
  * prompt-box.vala: Remove custom allocation code - everything
    works correctly without it. With it, entries are often under-
    or over- allocated, with the result being the active user's
    password entry sometimes does not have enough room to be visible.
  * background: Don't realize() this immediately - only start the
    image gathering thread during initialisation. Wait for the main
    window to be realised before passing its cairo surface to the
    background object and drawing the background for the first time.
  * slick-greeter.vala: Disconnect the event filter when the main
    window is destroyed, otherwise we can continue to receive
    events on the filter when we no longer have a backing GdkWindow
    to act upon (causing a segfault).
* Sat May 20 2017 sor.alexei@meowr.ru
- Update to version 1.0.3:
  * Add greeter icon support for budgie-desktop.
  * Remove some Unity elements from the man page.
  * Add missing man pages.
* Sun May 14 2017 sor.alexei@meowr.ru
- Update to version 1.0.2:
  * Fix session validation (gh#linuxmint/slick-greeter#25).
  * Session validation: Refactor in case the variable is null.
  * Update translations.
* Thu May  4 2017 sor.alexei@meowr.ru
- Initial package.
